#!/usr/bin/env python3
# @generated AUTOGENERATED file. Do not Change!

from enum import Enum


class ACEOutputType(Enum):
    drs = "drs"
    drshtml = "drshtml"
    drspp = "drspp"
    drsxml = "drsxml"
    fol = "fol"
    owlfss = "owlfss"
    owlfsspp = "owlfsspp"
    owlrdf = "owlrdf"
    owlxml = "owlxml"
    paraphrase = "paraphrase"
    paraphrase1 = "paraphrase1"
    paraphrase2 = "paraphrase2"
    pnf = "pnf"
    ruleml = "ruleml"
    syntax = "syntax"
    syntaxd = "syntaxd"
    syntaxdpp = "syntaxdpp"
    syntaxpp = "syntaxpp"
    tokens = "tokens"
    tptp = "tptp"
    MISSING_ENUM = ""

    @classmethod
    def _missing_(cls, value: object) -> "ACEOutputType":
        return cls.MISSING_ENUM



from gql_client.compiler.renderer_dataclasses import CustomScalar
from typing import Dict

custom_scalars: Dict[str, CustomScalar] = {
    "JSON": CustomScalar(
        name="JSON",
        type=dict,
    ),
}